import time
import threading
import logging
import socket
logging.basicConfig(format='%(asctime)s %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p')


class ElectricPowerThread(threading.Thread):

    def __init__(self, interuptingEvent, config, restClient):
        threading.Thread.__init__(self)
        self._sleepTime = config['sleep']
        self._interuptingEvent = interuptingEvent
        self._config = config
        self._taskName = self._config['name']
        self._restClient = restClient

    def run(self):
        try:
            from tplink_smartplug import SmartPlug
            plug = SmartPlug(self._config['ip'])
            alias = plug.command('{"system":{"get_sysinfo":{}}}')['alias']

            while not self._interuptingEvent.isSet():
                data = plug.command('{"emeter":{"get_realtime":{}}}')
                self._restClient.post(self.getEvent(data, alias))
                time.sleep(self._sleepTime)
        except socket.timeout as err:
            print(f"{err} from {self._config['name']}")
        except UnboundLocalError as ex:
            print(f"Exception UnboundLocalError from {self._config['name']}")
            print(ex)
        except Exception as ex:
            print(f"Exception from {self._config['name']}")
            print(ex)
            self._interuptingEvent.set()

        print("stopping services " + self._taskName)

    def getEvent(self, data, alias):
        return [{
                    'sensorName': 'power_' + alias,
                    'sensorType': self._taskName,
                    'value': data['power_mw']
            },{
                    'sensorName': 'totalwh_' + alias,
                    'sensorType': self._taskName,
                    'value': data['total_wh']
            }]