#!/usr/bin/python3
import sys
import json
import threading

from agent.networkTask import NetworkMonitorThread
from agent.motionTask import MotionMonitorThread
from agent.weatherTask import WeatherMonitorThread
from agent.textClient import TextClient
from agent.electricPowerTask import ElectricPowerThread


def main(argv):
    config = json.load(open(argv[1]))

    endEvent = threading.Event()
    client = TextClient(config)

    servicesMap = {
        'LanClient': NetworkMonitorThread,
        'MotionClient': MotionMonitorThread,
        'WeatherClient': WeatherMonitorThread,
        'ElectricClient': ElectricPowerThread
    }

    try:
        for serviceConfig in config['services']:
            print("Starting service: " + str(serviceConfig))
            thread = servicesMap[serviceConfig['name']]
            task = thread(endEvent, serviceConfig, client)
            task.start()
    except Exception as ex:
        print(ex)
        endEvent.set()
        sys.exit(1)


if __name__ == '__main__':
  main(sys.argv)
