import time
import threading
import logging
logging.basicConfig(format='%(asctime)s %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p')


class MotionMonitorThread(threading.Thread):

    def __init__(self, interuptingEvent, config, restClient):
        threading.Thread.__init__(self)
        self._sleepTime = config['sleep']
        self._interuptingEvent = interuptingEvent
        self._config = config
        self._restClient = restClient

    def run(self):
        import RPi.GPIO as GPIO
        GPIO.setwarnings(False)
        GPIO.setmode(GPIO.BOARD)
        GPIO.setup(self._config['pin'], GPIO.IN)

        try:
            wasSent = False
            while not self._interuptingEvent.isSet():
                if GPIO.input(self._config['pin']) == 1 and not wasSent:
                    self._restClient.post(self.getEvent())
                    wasSent = True
                else:
                    wasSent = False

                time.sleep(self._sleepTime)
        except Exception as ex:
            print(f"Exception from {self._config['name']}")
            print(ex)
            self._interuptingEvent.set()

        print("stopping services " + self._config['name'])

    def getEvent(self):
            return [{
                    'sensorName': self._config['name'],
                    'sensorType': self._config['name'],
                    'value': 0.
            }]