#!/usr/bin/python3
import logging
logging.getLogger("scapy.runtime").setLevel(logging.ERROR)
import logging
import threading
import time
import netifaces
logging.basicConfig(format='%(asctime)s %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p')


class NetworkMonitorThread(threading.Thread):

    def __init__(self, interuptingEvent, config, restClient):
        threading.Thread.__init__(self)
        self._interuptingEvent = interuptingEvent
        self._sleepTime = config['sleep']
        self._config = config
        self._restClient = restClient

    def run(self):
        from scapy.all import srp

        try:
            while not self._interuptingEvent.isSet():
                devices = self.getDevicesOnNetwork(self.getDefaultGateway(), srp)
                self._restClient.post(devices)
                time.sleep(self._sleepTime)
        except Exception as ex:
            print(f"Exception from {self._config['name']}")
            print(ex)
            self._interuptingEvent.set()

        print("stopping services " + self._config['name'])

    def getDevicesOnNetwork(self, gateway, srp):
        from scapy.all import Ether, ARP

        network = None
        try:
            network = gateway.replace('254', '0') + '/24'
        except Exception as ex:
            logging.error(ex)

        if network is not None:
            alive, dead = srp(Ether(dst="ff:ff:ff:ff:ff:ff") / ARP(pdst=network), timeout=1, verbose=0)
            return [
                {
                    'sensorName': alive[i][1].hwsrc,
                    'sensorType': self._config['name'],
                    'value': 0.
                } for i in range(len(alive))]

    def getDefaultGateway(self):
        gws = netifaces.gateways()
        return gws['default'][netifaces.AF_INET][0]