import time
import threading
from pip._internal.utils.misc import get_installed_distributions
import logging
logging.basicConfig(format='%(asctime)s %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p')


class UpdateThread(threading.Thread):

    def __init__(self, interuptingEvent, config, client):
        threading.Thread.__init__(self)
        self._interval = config['updateCheckingSleep']
        self._interuptingEvent = interuptingEvent
        self._client = client

    def run(self):
        if self.isNewRelease():
            self._interuptingEvent.set()
        else:
            while not self.isNewRelease():
                time.sleep(self._interval)

        print("stopping services update checker")
        self._interuptingEvent.set()


    def isNewRelease(self):
        def getCurrentVersion():
            keyVersion = {i.key: i.version for i in get_installed_distributions()}
            return keyVersion.get('network-monitor', 'not installed')

        def getLastReleasedVersion():
            return self._client.getVersion()

        currentVersion = getCurrentVersion()
        releasedVersion = getLastReleasedVersion()

        if currentVersion != releasedVersion:
            print("Current version " + currentVersion)
            print("New version " + releasedVersion)
            return True

        return False
