import time
import threading
import logging
from bme280 import bme280, bme280_i2c
logging.basicConfig(format='%(asctime)s %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p')

bme280_i2c.set_default_i2c_address(int('0x76', 0))
bme280_i2c.set_default_bus(1)
bme280.setup()


class WeatherMonitorThread(threading.Thread):

    def __init__(self, interuptingEvent, config, restClient):
        threading.Thread.__init__(self)
        self._sleepTime = config['sleep']
        self._interuptingEvent = interuptingEvent
        self._config = config
        self._taskName = self._config['name']
        self._restClient = restClient

    def run(self):
        try:
            while not self._interuptingEvent.isSet():
                data = bme280.read_all()
                self._restClient.post(self.getEvent(data))
                time.sleep(self._sleepTime)
        except OSError as ex:
            print(f"Exception OSError from {self._config['name']}")
            print(ex)
        except Exception as ex:
            print(f"Exception from {self._config['name']}")
            print(ex)
            self._interuptingEvent.set()

        print("stopping services " + self._taskName)

    def getEvent(self, data):
        return [{
                    'sensorName': 'temperature',
                    'sensorType': self._taskName,
                    'value': data.temperature
            }, {
                    'sensorName': 'pressure',
                    'sensorType': self._taskName,
                    'value': data.pressure
            }, {
                    'sensorName': 'humidity',
                    'sensorType': self._taskName,
                    'value': data.humidity
            }]